setup_group_term

Function setup_group_term 

fn setup_group_term(pid: UnixPid, job: &Job)
Setup the process group for the current pid as well term if interactive. Call from both the parent and child proc to avoid race conditions.